@@ -3,7 +3,7 @@ import asyncio
 import copy
 import random
 import traceback
-from typing import Union
+from typing import Optional, Union
 
 import socketio
 from socketio.exceptions import ConnectionError as SioConnectionError
@@ -34,14 +34,14 @@ class AsyncBotoy(Botoy):
             if asyncio.iscoroutinefunction(receiver):
                 coros.append(receiver(new_context))  # type: ignore
             else:
-                self.pool.submit(receiver, new_context)
+                self._pool.submit(receiver, new_context)
 
         try:
             await asyncio.gather(*coros)
         except Exception:
             logger.error(traceback.format_exc())
 
-    async def run(self, wait: bool = True, sio: socketio.AsyncClient = None):
+    async def run(self, wait: bool = True, sio: Optional[socketio.AsyncClient] = None):
         """运行
         :param wait: 是否阻塞
         """
@@ -50,8 +50,8 @@ class AsyncBotoy(Botoy):
 
         sio = sio or socketio.AsyncClient()
 
-        sio.event(self.connect)
-        sio.event(self.disconnect)
+        sio.event(self._connect)
+        sio.event(self._disconnect)
         sio.on("OnGroupMsgs", self._group_msg_handler)
         sio.on("OnFriendMsgs", self._friend_msg_handler)
         sio.on("OnEvents", self._event_handler)
@@ -60,8 +60,8 @@ class AsyncBotoy(Botoy):
             delay = 1
             while True:
                 try:
-                    logger.info(f"Connecting to the server[{self.config.address}]...")
-                    await sio.connect(self.config.address, transports=["websocket"])
+                    logger.info(f"Connecting to the server[{self.address}]...")
+                    await sio.connect(self.address, transports=["websocket"])
                 except (SioConnectionError, ValueError):
                     current_delay = delay + (2 * random.random() - 1) / 2
                     logger.error(
@@ -82,7 +82,7 @@ class AsyncBotoy(Botoy):
 
         except BaseException as e:
             await sio.disconnect()
-            self.pool.shutdown(False)
+            self._pool.shutdown(False)
             if isinstance(e, KeyboardInterrupt):
                 print("\b\b\b\bbye~")
             else:
@@ -90,7 +90,7 @@ class AsyncBotoy(Botoy):
 
         return sio
 
-    async def run_no_wait(self, sio: socketio.AsyncClient = None):
+    async def run_no_wait(self, sio: Optional[socketio.AsyncClient] = None):
         """不阻塞运行"""
         return await self.run(False, sio)
 
