@@ -1,5 +1,6 @@
 from ..model import FriendMsg, GroupMsg
-from ..refine import refine_pic_friend_msg, refine_pic_group_msg
+from ..parser import friend as fp
+from ..parser import group as gp
 
 
 def equal_content(string: str):
@@ -9,11 +10,11 @@ def equal_content(string: str):
         def inner(ctx):
             assert isinstance(ctx, (GroupMsg, FriendMsg))
             if isinstance(ctx, GroupMsg):
-                pic_ctx = refine_pic_group_msg(ctx)
+                pic_data = gp.pic(ctx)
             else:
-                pic_ctx = refine_pic_friend_msg(ctx)
-            if pic_ctx is not None:
-                content = pic_ctx.Content
+                pic_data = fp.pic(ctx)
+            if pic_data is not None:
+                content = pic_data.Content
             else:
                 content = ctx.Content
             if content == string:
