@@ -13,7 +13,7 @@ import os
 import re
 from pathlib import Path
 from types import ModuleType
-from typing import Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import colorama
 from prettytable import PrettyTable
@@ -46,6 +46,18 @@ class Plugin:
 
     def disable(self):
         self._enabled = False
+        if self.module:
+            when_disable = self.module.__dict__.get("when_disable")
+            if when_disable:
+                when_disable()
+
+    @property
+    def when_connected(self) -> Optional[Callable[[List[int], str, int], Any]]:
+        return self.module.__dict__.get("when_connected")
+
+    @property
+    def when_disconnected(self) -> Optional[Callable[[List[int], str, int], Any]]:
+        return self.module.__dict__.get("when_disconnected")
 
     @property
     def loaded(self) -> bool:
@@ -256,6 +268,22 @@ class PluginManager:
                 receivers.append(plugin.receive_events)
         return receivers
 
+    @property
+    def when_connected_funcs(self) -> List[Callable[[List[int], str, int], Any]]:
+        funcs = []
+        for plugin in self.plugins.values():
+            if plugin.enabled and plugin.when_connected:
+                funcs.append(plugin.when_connected)
+        return funcs
+
+    @property
+    def when_disconnected_funcs(self) -> List[Callable[[List[int], str, int], Any]]:
+        funcs = []
+        for plugin in self.plugins.values():
+            if plugin.enabled and plugin.when_disconnected:
+                funcs.append(plugin.when_disconnected)
+        return funcs
+
     @property
     def info(self) -> str:
         """插件信息"""
